--- destinations.py	2005-01-18 20:08:21.000000000 +0100
+++ modified_destinations.py	2005-02-16 20:22:13.000000000 +0100
@@ -22,12 +22,15 @@
     'MultiDestination',
     'MultiSorterBase',
     'MultiSorter',
+    'SMTP',
 ]
 
 import os
 import re
 import types
 import email.Utils
+import getpass
+import smtplib
 
 # Only on Unix
 try:
@@ -1045,3 +1048,57 @@
             return 'MultiGuesser (default %s)' % self.default.deliver_message(
                 msg, delivered_to, received)
         return 'MultiGuesser (%s)' % matched
+
+
+#######################################
+class SMTP(DeliverySkeleton):
+    '''SMTP destination.
+
+    Parameters:
+
+      host - mailserver where to send the mails
+      send_to - email address of the real recipient
+      from - your email address for error messages (default: user@hostname)
+    '''
+    _confitems = (
+        {'name' : 'host', 'type' : str, 'default' : 'localhost'},
+        {'name' : 'send_to', 'type' : str, 'default' : None},
+        {'name' : 'from', 'type' : str, 'default' : None},
+        {'name' : 'configparser', 'type' : types.InstanceType, 'default' : None},
+    )
+
+    def initialize(self):
+        self.log.trace()
+
+        if self.conf['send_to'] == None:
+        	raise getmailConfigurationError('missing required configuration'
+                ' parameter %s' % 'send_to')
+        if self.conf['from'] == None:
+        	username = getpass.getuser()
+        	self.conf['from'] = username + '@' + localhostname()
+
+    def __str__(self):
+        self.log.trace()
+        return 'SMTP %s' % self.conf['host']
+
+    def showconf(self):
+        self.log.info('SMTP(%s)\n' % self._confstring())
+
+    def _deliver_message(self, msg, delivered_to, received):
+        self.log.trace()
+
+        try:        
+        	server = smtplib.SMTP(self.conf['host'])
+        	server.sendmail(self.conf['from'], [self.conf['send_to']], msg.flatten(delivered_to, received))
+        	server.quit()
+        except smtplib.SMTPException, why:
+        	try: server.quit()
+        	except: pass
+        	raise getmailDeliveryError('failure sending mail to "' + self.conf['send_to'] + \
+        		'" at ' + self.conf['host'] + ' from "' + self.conf['from'] + '". Server '\
+        		'said: ' + str(why))
+        
+        self.log.debug('SMTP finished')
+        return self
+
+#######################################
